==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/WebSnackbarDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { VoidEventArgsDescriptionMetadata } from "./VoidEventArgsDescriptionMetadata";
import { WebSnackbarDescription } from "./WebSnackbarDescription";
/**
 * @hidden
 */
var WebSnackbarDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebSnackbarDescriptionMetadata, _super);
    function WebSnackbarDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebSnackbarDescriptionMetadata.b = function (a) {
        if (WebSnackbarDescriptionMetadata.a == null) {
            WebSnackbarDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebSnackbarDescriptionMetadata.c(WebSnackbarDescriptionMetadata.a);
        }
        if (a.g(WebSnackbarDescriptionMetadata.a)) {
            return;
        }
        a.s(WebSnackbarDescriptionMetadata.a);
        VoidEventArgsDescriptionMetadata.d(a);
    };
    WebSnackbarDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:Snackbar");
        a.item("Open", "Boolean");
        a.item("DisplayTime", "Number:double");
        a.item("KeepOpen", "Boolean");
        a.item("ActionText", "String");
        a.item("ActionRef", "EventRef::action");
    };
    WebSnackbarDescriptionMetadata.d = function (a) {
        WebSnackbarDescriptionMetadata.b(a);
        a.u("WebSnackbar", function () { return new WebSnackbarDescription(); });
        a.t("WebSnackbar", WebSnackbarDescriptionMetadata.a);
    };
    WebSnackbarDescriptionMetadata.$t = markType(WebSnackbarDescriptionMetadata, 'WebSnackbarDescriptionMetadata');
    WebSnackbarDescriptionMetadata.a = null;
    return WebSnackbarDescriptionMetadata;
}(Base));
export { WebSnackbarDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebSnackbarDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { VoidEventArgsDescriptionMetadata } from "./VoidEventArgsDescriptionMetadata";
import { WebSnackbarDescription } from "./WebSnackbarDescription";
/**
 * @hidden
 */
var WebSnackbarDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebSnackbarDescriptionMetadata, _super);
    function WebSnackbarDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebSnackbarDescriptionMetadata.b = function (a) {
        if (WebSnackbarDescriptionMetadata.a == null) {
            WebSnackbarDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebSnackbarDescriptionMetadata.c(WebSnackbarDescriptionMetadata.a);
        }
        if (a.j(WebSnackbarDescriptionMetadata.a)) {
            return;
        }
        a.y(WebSnackbarDescriptionMetadata.a);
        VoidEventArgsDescriptionMetadata.d(a);
    };
    WebSnackbarDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:Snackbar");
        a.item("__tagNameWC", "String:igc-snackbar");
        a.item("Open", "Boolean");
        a.item("DisplayTime", "Number:double");
        a.item("KeepOpen", "Boolean");
        a.item("ActionText", "String");
        a.item("ActionRef", "EventRef::action");
    };
    WebSnackbarDescriptionMetadata.d = function (a) {
        WebSnackbarDescriptionMetadata.b(a);
        a.aa("WebSnackbar", function () { return new WebSnackbarDescription(); });
        a.z("WebSnackbar", WebSnackbarDescriptionMetadata.a);
    };
    WebSnackbarDescriptionMetadata.$t = markType(WebSnackbarDescriptionMetadata, 'WebSnackbarDescriptionMetadata');
    WebSnackbarDescriptionMetadata.a = null;
    return WebSnackbarDescriptionMetadata;
}(Base));
export { WebSnackbarDescriptionMetadata };
